@@ -1,7 +1,16 @@
 package Mojolicious::Che;
-use Mojo::Base 'Mojolicious';
+use Mojo::Base::Che 'Mojolicious';
+use Mojo::Loader qw(load_class);
 
-our $VERSION = '0.007';
+our $VERSION = '0.010';
+
+=pod
+
+=head1 VERSION
+
+0.010
+
+=cut
 
 sub поехали {
   my $app = shift;
@@ -45,7 +54,7 @@ sub плугины {# Плугины из конфига
   my $plugins = $conf->{'mojo_plugins'} || $conf->{'mojo'}{'plugins'} || $conf->{'плугины'}
     || return;
   map {
-    $app->plugin(@$_);
+    ref $_->[1] eq 'CODE' ? $app->plugin($_->[0] => $app->${ \$_->[1] }) : $app->plugin(@$_);
     $app->log->debug("Enable plugin [$_->[0]]");
   } @$plugins;
 }
@@ -86,11 +95,22 @@ sub базы {# обрабатывает dbh конфига
 
 sub запросы {# обрабатывает sth конфига
   my $app = shift;
+  my $dbh = eval { $app->dbh }
+    or return;
+  my %arg = @_;
   my $conf = $app->config;
-  my $c_sth = $conf->{sth} || $conf->{'запросы'};
-  return unless $c_sth && ref($c_sth) eq 'HASH' && keys %$c_sth;
-  my $dbh = $app->dbh;
-  my $sth = $app->sth;
+  
+  my $c_sth = $arg{sth} || $conf->{sth} || $conf->{'запросы'} || {};
+  my $c_pos = $arg{pos} || $conf->{pos} || $conf->{'посы'} || {};
+    
+  return unless ($c_sth && ref($c_sth) eq 'HASH' && keys %$c_sth)
+    || ($c_pos && ref($c_pos) eq 'HASH' && keys %$c_pos);
+  
+  my $sth = do {
+    has sth => sub {{};}
+      unless $app->can('sth');
+    $app->sth;
+  };
   
   while (my ($db, $h) = each %$c_sth) {
     while (my ($st, $sql) = each %$h) {
@@ -98,6 +118,16 @@ sub запросы {# обрабатывает sth конфига
       $app->log->debug("Подготовился запрос [app->sth->{$db}{$st}]");
     }
   }
+  
+  my $sth_pos;
+  while (my ($db, $arr) = each %$c_pos) {
+    for my $item (@$arr) {
+      $sth_pos ||= $app->_class('DBIx::POS::Sth');
+      my $pos_module = $app->_class(shift @$item);
+      $sth->{$db}{$pos_module} = $sth_pos->new($dbh->{$db}, $pos_module->new(@$item));
+    }
+  }
+  
   $sth;
 }
 
@@ -165,6 +195,23 @@ sub спейсы {
   push @{$app->routes->namespaces}, @$ns;
 }
 
+sub Mojolicious::Routes::is_hidden0000 {
+  my ($self, $method) = @_;
+  my $h = $self->{hiding} ||= {map { $_ => 1 } @{$self->hidden}};
+  #~ return !!($h->{$method} || index($method, '_') == 0 || $method !~ /[a-z]/);
+  #~ return !!($h->{$method} || index($method, '_') == 0);
+   return !!($h->{$method} || $method =~ /^_/ || $method =~ /^[A-Z_]+$/);
+}
+
+sub _class {
+  my $self = shift;
+  my $class  = shift;
+  my $e;
+  $e = load_class($class)# success undef
+    and die $e;
+  return $class;
+}
+
 1;
 
 =pod
@@ -177,17 +224,17 @@ sub спейсы {
 
 ¡ ¡ ¡ ALL GLORY TO GLORIA ! ! !
 
-=head1 VERSION
-
-0.007
-
 =head1 NAME
 
 Mojolicious::Che - Мой базовый модуль для приложений Mojolicious. Нужен только развернутый конфиг.
 
+=head1 Важно
+
+Пропатчен метод C< sub Mojolicious::Routes::is_hidden > поэтому действия в маршрутах разрешены не только латиницей.
+
 =head1 SYNOPSIS
 
-  use Mojo::Base 'Mojolicious::Che';
+  use Mojo::Base::Che 'Mojolicious::Che';
   
   sub startup {
     my $app = shift;
@@ -261,6 +308,13 @@ Mojolicious::Che - Мой базовый модуль для приложени
       now => "select now();"
     },
   },
+  # DBIx::POS::Sth
+  # will be as has $app->sth->{<dbh name>}{<POS module name>}->sth(<statement name>, ...)
+  pos => {
+    main => [# hashref
+      ['POS::Foo' => template => {var1=>1,}],
+    ],
+  },
     
   # 'плугины'=> [
   mojo_plugins=>[ 
